utils
=====

.. automodule:: tropycal.utils


Generic Utilities
-----------------

   .. autosummary::
      :toctree: ./

      accumulated_cyclone_energy
      wind_to_category
      category_to_wind
      calc_ensemble_ellipse
      classify_subtropical
      create_storm_dict
      dropsonde_mslp_estimate
      generate_nhc_cone
      get_basin
      get_storm_classification
      get_storm_type
      get_two_current
      get_two_archive
      knots_to_mph
      nhc_cone_radii
      ships_parser


Cartopy Utilities
-----------------

   .. autosummary::
      :toctree: ./

      add_tropycal
      plot_storm
      plot_two
      plot_cone


Colors
------

   .. autosummary::
      :toctree: ./

      get_colors_sshws
      get_colors_ef
      get_colors_pph